Command class abstract

Constructors

Command({int? id, String? key, String? group, Map<String, String>? params, String? companyId})

Properties

canBeGrouped bool
no setter
companyId String
no setter
dependOn List<String>
no setter
group String
no setter
grouped List<Command>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
no setter
ids List<int>
no setter
key String
no setter
language String
no setter
name String
no setter
params Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortInfo CommandShortInfo
no setter

Methods

execute<T>(ICommandService cmdService) Future<CommandResult<T>>
grpcOptions() → CallOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCompany(String companyId) → void
setGroup(List<Command> list) → void
setLanguage(String lang) → void
toLog() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited