CommandEventResult class

Constructors

CommandEventResult({required String cmd, required String key, required String group, dynamic data})

Properties

cmd String
final
data → dynamic
final
group String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited