CommandLog class

Constructors

CommandLog(String action, Command cmd, {bool isClient = false, CommandResult? result})

Properties

action String
final
error Error?
Error? error - error if it happened
finalinherited
exception Object?
Exception? exception - exception if it happened
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isClient bool
getter/setter pair
key String?
finalinherited
logLevel → LogLevel?
LogLevel logLevel - to control logging output
finalinherited
message String?
String message - message describes what happened
finalinherited
pen ↔ AnsiPen?
AnsiPen? pen - sets your own log color for console
getter/setter pairinherited-setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
StackTrace?] stackTrace - stackTrace if exception or error happened
finalinherited
time DateTime
Internal time when the log occurred
no setterinherited
title String
Title of Talker log
getter/setter pairinherited-setter

Methods

generateTextMessage({TimeFormat timeFormat = TimeFormat.timeAndSeconds}) String
Internal method that generates a complete message about the event
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited