ICommandRepository class abstract

Constructors

ICommandRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String cmd, String group, String key, Map<String, String> params, String companyId, {int timeOffset = 0}) Future<void>
clear() Future<void>
delete(int id) Future<void>
get() Future<List<CommandData>>
isExist(String cmd, String companyId, {String? group}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postponeTill(int id, int delaySeconds) Future<void>
queueLength() Future<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited