ICommandService class abstract

Constructors

ICommandService()

Properties

backendAvailable Stream<bool>
no setter
hashCode int
The hash code for this object.
no setterinherited
queueLength Stream<int>
no setter
queueUpdated Stream<void>
no setter
result Stream<CommandEventResult>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute<T>(Command cmd, {bool immediately = false, int timeOffset = 0}) Future<CommandResult<T>>
finalizeGroupCommand(Command cmd, CommandResult result) Future<void>
invoke(String event, Map<String, dynamic> data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event) Stream<Map<String, dynamic>?>
returnCommandResult(String cmd, String key, String group, {dynamic data}) → void
setBackendAvailability(bool state) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited